@@ -28,7 +28,9 @@ class TableauScraper:
     data = {}
     dashboard: str = ""
     tableauData = {}
-    dataSegments = {}
+    dataSegments = {}  # persistent data dictionary
+    parameters = {}  # persist parameter controls
+    filters = {}  # persist filters per worksheet
     logger = logging.getLogger("tableauScraper")
     delayMs = 500  # delay between actions (select/dropdown)
     lastActionTime = 0
@@ -92,7 +94,11 @@ class TableauScraper:
                 presModelMap = self.data["secondaryInfo"]["presModelMap"]
                 self.dataSegments = presModelMap["dataDictionary"][
                     "presModelHolder"]["genDataDictionaryPresModel"]["dataSegments"]
+                self.parameters = utils.getParameterControlInput(
+                    self.info)
             self.dashboard = self.info["sheetName"]
+            self.filters = utils.getFiltersForAllWorksheet(
+                self.data, self.info, rootDashboard=self.dashboard)
         except (AttributeError):
             raise TableauException(message=r)
 
