@@ -23,6 +23,7 @@ class TableauWorkbook:
         self._originalInfo = originalInfo
 
     def updateFullData(self, cmdResponse):
+        # update data dictionary if present
         if (("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]) and
                 ("dataDictionary" in cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"])):
             presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
@@ -39,6 +40,41 @@ class TableauWorkbook:
         else:
             self._scraper.logger.warning(
                 f"no data dictionary present in response")
+        # update parameters if present
+        self._scraper.parameters = self.getParameters()
+        if ("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]):
+            presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
+            newParameters = tableauscraper.utils.getParameterControlVqlResponse(
+                presModel)
+            newParameterscsp = copy.deepcopy(newParameters)
+            for newParam in newParameterscsp:
+                found = False
+                for param in self._scraper.parameters:
+                    if newParam["parameterName"] == param["parameterName"]:
+                        found = True
+                if not found:
+                    self._scraper.parameters.append(newParam)
+        # update filters if present
+        if ("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]):
+            newFilters = tableauscraper.utils.getFiltersForAllWorksheet(
+                data=cmdResponse, info=None, rootDashboard=self._scraper.dashboard, cmdResponse=True)
+            newFilterscsp = copy.deepcopy(newFilters)
+            for worksheet in newFilterscsp:
+                if worksheet not in self._scraper.filters:
+                    self._scraper.filters[worksheet] = newFilters[worksheet]
+                else:
+                    for newFilter in newFilters[worksheet]:
+                        found = False
+                        foundFilterIndex = -1
+                        for idx, filter in enumerate(self._scraper.filters[worksheet]):
+                            if newFilter["globalFieldName"] == filter["globalFieldName"]:
+                                found = True
+                                foundFilterIndex = idx
+                        if not found:
+                            self._scraper.filters[worksheet].append(newFilter)
+                        else:
+                            del self._scraper.filters[worksheet][foundFilterIndex]
+                            self._scraper.filters[worksheet].append(newFilter)
 
     def getWorksheetNames(self):
         return tableauscraper.utils.getWorksheetNames(self)
@@ -64,27 +100,14 @@ class TableauWorkbook:
             )
 
     def getParameters(self):
-        if self.cmdResponse:
-            presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-            return tableauscraper.utils.getParameterControlVqlResponse(presModel)
-        else:
-            return tableauscraper.utils.getParameterControlInput(self._originalInfo)
+        return self._scraper.parameters
 
     def setParameter(self, inputName, value):
-        parameterNames = []
-        if self.cmdResponse:
-            presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-            parameterNames = [
-                t["parameterName"]
-                for t in tableauscraper.utils.getParameterControlVqlResponse(presModel)
-                if t["column"] == inputName
-            ]
-        else:
-            parameterNames = [
-                t["parameterName"]
-                for t in tableauscraper.utils.getParameterControlInput(self._originalInfo)
-                if t["column"] == inputName
-            ]
+        parameterNames = [
+            t["parameterName"]
+            for t in self._scraper.parameters
+            if t["column"] == inputName
+        ]
         if len(parameterNames) == 0:
             self._scraper.logger.error(f"column {inputName} not found")
             return TableauWorkbook(
