@@ -35,6 +35,7 @@ class TableauWorksheet:
         self._data_dictionnary = dataFull
 
     def updateFullData(self, cmdResponse):
+        # persist data dictionary
         if (("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]) and
                 ("dataDictionary" in cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"])):
             presModel = cmdResponse["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
@@ -65,6 +66,28 @@ class TableauWorksheet:
             self._scraper.logger.warning(
                 f"no data dictionary present in response")
 
+        # update filters if present
+        if ("applicationPresModel" in cmdResponse["vqlCmdResponse"]["layoutStatus"]):
+            newFilters = tableauscraper.utils.getFiltersForAllWorksheet(
+                data=cmdResponse, info=None, rootDashboard=self._scraper.dashboard, cmdResponse=True)
+            newFilterscsp = copy.deepcopy(newFilters)
+            for worksheet in newFilterscsp:
+                if worksheet not in self._scraper.filters:
+                    self._scraper.filters[worksheet] = newFilters[worksheet]
+                else:
+                    for newFilter in newFilters[worksheet]:
+                        found = False
+                        foundFilterIndex = -1
+                        for idx, filter in enumerate(self._scraper.filters[worksheet]):
+                            if newFilter["globalFieldName"] == filter["globalFieldName"]:
+                                found = True
+                                foundFilterIndex = idx
+                        if not found:
+                            self._scraper.filters[worksheet].append(newFilter)
+                        else:
+                            del self._scraper.filters[worksheet][foundFilterIndex]
+                            self._scraper.filters[worksheet].append(newFilter)
+
     def getColumns(self) -> List[str]:
         if self.cmdResponse:
             presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
@@ -85,20 +108,7 @@ class TableauWorksheet:
             ]
 
     def getFilters(self) -> List[str]:
-        if self.cmdResponse:
-            presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-            selectedFilters = tableauscraper.utils.getSelectedFilters(
-                presModel,
-                self.name
-            )
-        else:
-            presModel = tableauscraper.utils.getPresModelVizInfo(
-                self._originalInfo)
-            selectedFilters = tableauscraper.utils.getSelectedFilters(
-                tableauscraper.utils.getPresModelVizInfo(self._originalInfo),
-                self.name
-            )
-        return tableauscraper.utils.listFilters(presModel, self.name, selectedFilters)
+        return self._scraper.filters[self.name] if self.name in self._scraper.filters else []
 
     def setFilter(self, columnName, value, dashboardFilter=False, membershipTarget=True, filterDelta=False):
         try:
@@ -116,7 +126,10 @@ class TableauWorksheet:
                     "selection": t["selection"],
                     "selectionAlt": t["selectionAlt"],
                     "values": t["values"],
-                    "ordinal": t["ordinal"]
+                    "ordinal": t["ordinal"],
+                    "storyboard": t["storyboard"] if "storyboard" in t else None,
+                    "storyboardId": t["storyboardId"] if "storyboardId" in t else None,
+                    "dashboard": t["dashboard"] if "dashboard" in t else self._scraper.dashboard
                 }
                 for t in self.getFilters()
                 if t["column"] == columnName
@@ -151,7 +164,10 @@ class TableauWorksheet:
                     selection=filter[0]["indices"],
                     selectionToRemove=[] if not filterDelta else selectedIndex,
                     membershipTarget=membershipTarget,
-                    filterDelta=filterDelta
+                    filterDelta=filterDelta,
+                    storyboard=filter[0]["storyboard"],
+                    storyboardId=filter[0]["storyboardId"],
+                    dashboard=filter[0]["dashboard"]
                 )
             self.updateFullData(r)
             return tableauscraper.dashboard.getWorksheetsCmdResponse(self._scraper, r)
@@ -169,13 +185,24 @@ class TableauWorksheet:
     def getSelectableItems(self) -> List[str]:
         if self.cmdResponse:
             presModel = self._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-            return [
+            selectableItems = [
                 {
                     "column": t["fieldCaption"],
                     "values": next(iter([y for y in tableauscraper.utils.getData(self._data_dictionnary, [t]).values()]), [])
                 }
                 for t in tableauscraper.utils.getIndicesInfoVqlResponse(presModel, self.name, noSelectFilter=True)
             ]
+            if len(selectableItems) == 0:
+                indicesInfo = tableauscraper.utils.getIndicesInfoStoryPoint(
+                    presModel, self.name, noSelectFilter=True)
+                return [
+                    {
+                        "column": t["fieldCaption"],
+                        "values": next(iter([y for y in tableauscraper.utils.getData(self._data_dictionnary, [t]).values()]), [])
+                    }
+                    for t in indicesInfo
+                ]
+            return selectableItems
         else:
             presModel = tableauscraper.utils.getPresModelVizData(
                 self._originalData)
@@ -209,7 +236,15 @@ class TableauWorksheet:
                 if t["fieldCaption"] == column
             ]
             if len(columnObj) == 0:
-                return []
+                indicesInfo = tableauscraper.utils.getIndicesInfoStoryPoint(
+                    presModel, self.name, noSelectFilter=True)
+                columnObj = [
+                    t
+                    for t in indicesInfo
+                    if t["fieldCaption"] == column
+                ]
+                if len(columnObj) == 0:
+                    return []
             frameData = tableauscraper.utils.getData(
                 self._data_dictionnary, [columnObj[0]]
             )
