@@ -320,10 +320,11 @@ def getDataFullCmdResponse(presModel, originSegments, dataSegments={}):
     originSegmentscp = copy.deepcopy(originSegments)
     dataColumns = []
     for d in list(originSegmentscp):
-        dataColumns.extend(originSegmentscp[d]["dataColumns"])
+        if (originSegmentscp[d] is not None):
+            dataColumns.extend(originSegmentscp[d]["dataColumns"])
 
     for d in list(dataSegmentscp):
-        if d not in originSegments:
+        if (d not in originSegments) and (dataSegmentscp[d] is not None):
             dataColumns.extend(dataSegmentscp[d]["dataColumns"])
 
     dataFull = {}
@@ -555,7 +556,7 @@ def getParameterControlVqlResponse(presModel):
 
 def getSelectedFilters(presModel, worksheetName):
     zones = presModel["workbookPresModel"]["dashboardPresModel"]["zones"]
-    return [
+    selectedFilters = [
         {
             "fn": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["fn"],
             "columnFullNames": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["columnFullNames"],
@@ -570,9 +571,41 @@ def getSelectedFilters(presModel, worksheetName):
         and ("categoricalFilter" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"])
         and zones[z]["worksheet"] == worksheetName
     ]
+    if len(selectedFilters) == 0:
+        storypoints = [
+            zones[z]["presModelHolder"]["flipboard"]["storyPoints"]
+            for z in list(zones)
+            if zones[z] is not None
+            and ("presModelHolder" in zones[z])
+            and ("flipboard" in zones[z]["presModelHolder"])
+            and ("storyPoints" in zones[z]["presModelHolder"]["flipboard"])
+        ]
+        if len(storypoints) > 0:
+            storypoint = storypoints[0]
+            keys = list(storypoint.keys())
+            selectedFilters = []
+            for key in keys:
+                zones = storypoint[key]["dashboardPresModel"]["zones"]
+                selectedFilters.extend([
+                    {
+                        "fn": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["fn"],
+                        "columnFullNames": zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["columnFullNames"],
+                        "domainTables":zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"]["categoricalFilter"]["domainTables"],
+                    }
+                    for z in list(zones)
+                    if zones[z] is not None
+                    and ("worksheet" in zones[z])
+                    and ("presModelHolder" in zones[z])
+                    and ("quickFilterDisplay" in zones[z]["presModelHolder"])
+                    and ("quickFilter" in zones[z]["presModelHolder"]["quickFilterDisplay"])
+                    and ("categoricalFilter" in zones[z]["presModelHolder"]["quickFilterDisplay"]["quickFilter"])
+                    and zones[z]["worksheet"] == worksheetName
+                ])
+            return selectedFilters
+    return selectedFilters
 
 
-def listFilters(presModel, worksheetName, selectedFilters):
+def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
     zones = presModel["workbookPresModel"]["dashboardPresModel"]["zones"]
     filters = [
         json.loads(zones[z]["presModelHolder"]["visual"]["filtersJson"])
@@ -609,6 +642,65 @@ def listFilters(presModel, worksheetName, selectedFilters):
                         "selectionAlt": [it for it in selectedFilters if it["fn"] == f"[{c[1][0]}].[{c[1][1]}]"]
                     })
         return entries
+    else:
+        storypoints = [
+            zones[z]["presModelHolder"]["flipboard"]["storyPoints"]
+            for z in list(zones)
+            if zones[z] is not None
+            and ("presModelHolder" in zones[z])
+            and ("flipboard" in zones[z]["presModelHolder"])
+            and ("storyPoints" in zones[z]["presModelHolder"]["flipboard"])
+        ]
+        if len(storypoints) > 0:
+            storypoint = storypoints[0]
+            keys = list(storypoint.keys())
+            filtersList = []
+            for key in keys:
+                storyboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["storyboard"]
+                storyboardId = storypoint[key]["dashboardPresModel"]["sheetPath"]["storyPointId"]
+                dashboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["sheetName"] if storypoint[
+                    key]["dashboardPresModel"]["sheetPath"]["isDashboard"] else rootDashboard
+                zones = storypoint[key]["dashboardPresModel"]["zones"]
+                filters = [
+                    json.loads(zones[z]["presModelHolder"]
+                               ["visual"]["filtersJson"])
+                    for z in list(zones)
+                    if zones[z] is not None
+                    and ("worksheet" in zones[z])
+                    and ("presModelHolder" in zones[z])
+                    and ("visual" in zones[z]["presModelHolder"])
+                    and ("filtersJson" in zones[z]["presModelHolder"]["visual"])
+                    and zones[z]["worksheet"] == worksheetName
+                ]
+                if len(filters) != 0:
+                    entries = []
+                    for arr in filters:
+                        result = [
+                            {
+                                "columns": [(z["caption"], z["name"], z["ordinal"]) for z in t["table"]["schema"]],
+                                "values": [z["t"][0]["v"] for z in t["table"]["tuples"] if "t" in z and len(z["t"]) != 0],
+                                "selection": [z["t"][0]["v"] for z in t["table"]["tuples"] if ("t" in z) and (len(z["t"]) != 0) and ("s" in z) and (z["s"] == True)]
+                            }
+                            for t in arr
+                            if "table" in t
+                            and "schema" in t["table"]
+                            and "tuples" in t["table"]
+                        ]
+                        for r in result:
+                            for c in r["columns"]:
+                                entries.append({
+                                    "column": c[0],
+                                    "ordinal": c[2],
+                                    "values": r["values"],
+                                    "globalFieldName": f"[{c[1][0]}].[{c[1][1]}]",
+                                    "selection": r["selection"],
+                                    "selectionAlt": [it for it in selectedFilters if it["fn"] == f"[{c[1][0]}].[{c[1][1]}]"],
+                                    "storyboard": storyboard,
+                                    "storyboardId": storyboardId,
+                                    "dashboard": dashboard
+                                })
+                    filtersList.extend(entries)
+            return filtersList
     return []
 
 
@@ -618,3 +710,36 @@ def getTooltipText(tooltipServerCmdResponse):
         return json.loads(tooltipText)["htmlTooltip"]
     else:
         return ""
+
+
+def getFiltersForAllWorksheet(data, info, rootDashboard, cmdResponse=False):
+    filterResult = {}
+    if cmdResponse:
+        presModel = data["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
+        worksheets = listWorksheetCmdResponse(presModel)
+        for worksheet in worksheets:
+            selectedFilters = getSelectedFilters(
+                presModel,
+                worksheet["worksheet"]
+            )
+            filters = listFilters(presModel,
+                                  worksheet["worksheet"], selectedFilters, rootDashboard)
+            filterResult[worksheet["worksheet"]] = filters
+    else:
+        presModelMapVizData = getPresModelVizData(data)
+        presModelMapVizInfo = getPresModelVizInfo(info)
+        if presModelMapVizData is not None:
+            worksheets = listWorksheet(presModelMapVizData)
+        elif presModelMapVizInfo is not None:
+            worksheets = listWorksheetInfo(presModelMapVizInfo)
+            if len(worksheets) == 0:
+                worksheets = listStoryPointsInfo(presModelMapVizInfo)
+        else:
+            worksheets = []
+        for worksheet in worksheets:
+            selectedFilters = getSelectedFilters(
+                presModelMapVizInfo, worksheet)
+            filters = listFilters(presModelMapVizInfo,
+                                  worksheet, selectedFilters, rootDashboard)
+            filterResult[worksheet] = filters
+    return filterResult
